Usage
aniplotevents(x, w, noiseType = c("white", "red"), alpha = 0.05,
main = "Animation plot of events", xlab = "t", ylab = "x",
movie.name = "animation.gif", interval = 0.05, ani.width = 1000,
ani.height = 400, outdir = getwd())Arguments
x
a vector or a time series.
w
a scalar specifying the size of the sliding
window.
noiseType
background noise type assumed for x.
There are two options: white noise or red noise.
alpha
the significance level. When the noise test
p value of the subsequence is smaller than this
significance level, it is defined as a potential event.
main
title of the animiation plot; default is
`Animation plot of event detection'.
xlab
x label of the animation plot; default is
`t'.
ylab
y label of the animation plot; default is
`x'.
movie.name
name of the output gif file; default is
`animation.gif'.
interval
a positive number to set the time
interval of the animation (unit in seconds); default is
0.05.
ani.width
width of the gif file (unit in px),
default is 1000.
ani.height
height of the gif file (unit in px);
default is 400.
outdir
character: specify the output directory
when exporting the animations; default to be the current
working directory.